antares.apps.flow.api package — Antares 0.0.2 documentation

# antares.apps.flow.api package

## Submodules

## antares.apps.flow.api.api_case_document_view module

## antares.apps.flow.api.api_case_history_view module

## antares.apps.flow.api.api_case_note_list_view module

## antares.apps.flow.api.api_case_properties_view module

## antares.apps.flow.api.api_case_set_tracking_option_view module

## antares.apps.flow.api.api_case_update_name_view module

## antares.apps.flow.api.api_case_update_note_view module

## antares.apps.flow.api.api_case_update_priority_view module

## antares.apps.flow.api.api_case_update_property_view module

## antares.apps.flow.api.api_forward_view module

## antares.apps.flow.api.api_inbox_active_cases_view module

## antares.apps.flow.api.api_inbox_completed_cases_view module

## antares.apps.flow.api.api_inbox_created_cases_view module

## Module contents